@@ -72,11 +72,12 @@ and XMP metadata of images in various formats.")
     (build-system gnu-build-system)
     (inputs
      `(;; ("libchamplain" ,libchamplain)
-       ("intltool" ,intltool)
        ("lcms" ,lcms)
        ("exiv2" ,exiv2)
        ("libpng" ,libpng)
-       ("gtk+" ,gtk+-2)
+       ("gtk+" ,gtk+-2)))
+    (native-inputs
+     `(("intltool" ,intltool)
        ("pkg-config" ,pkg-config)))
     (home-page "http://geeqie.sourceforge.net")
     (synopsis "Lightweight GTK+ based image viewer")
