@@ -1,5 +1,6 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2012, 2013 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2012, 2013, 2014 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2014 Mark H Weaver <mhw@netris.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -28,12 +29,14 @@
   #:use-module (gnu packages guile)
   #:use-module (gnu packages perl)
   #:use-module (gnu packages which)
-  #:use-module (gnu packages pkg-config))
+  #:use-module (gnu packages texinfo)
+  #:use-module (gnu packages pkg-config)
+  #:use-module (srfi srfi-1))
 
 (define-public libtasn1
   (package
     (name "libtasn1")
-    (version "3.3")
+    (version "3.4")
     (source
      (origin
       (method url-fetch)
@@ -41,8 +44,13 @@
                           version ".tar.gz"))
       (sha256
        (base32
-        "1h1sz5py8zlg4yczybr6wa925pyadvjcxrdmhilwaqqgs4n2lrcj"))))
+        "1j5cwsjk9wai700ljsr5qyzywijrr5ba05hhg4mkgqlg8mx50lzk"))))
     (build-system gnu-build-system)
+    (native-inputs `(("perl" ,perl)
+
+                     ;; XXX: For some reason, libtasn1.info wants to be
+                     ;; rebuilt, so we must provide 'makeinfo'.
+                     ("texinfo" ,texinfo)))
     (home-page "http://www.gnu.org/software/libtasn1/")
     (synopsis "ASN.1 library")
     (description
@@ -55,18 +63,24 @@ specifications.")
 (define-public gnutls
   (package
     (name "gnutls")
-    (version "3.2.4")
+    (version "3.2.12")
     (source (origin
              (method url-fetch)
              (uri
               ;; Note: Releases are no longer on ftp.gnu.org since the
               ;; schism (after version 3.1.5).
-              (string-append "mirror://gnupg/gnutls/v3.2/gnutls-"
-                             version ".tar.xz"))
+              (string-append "mirror://gnupg/gnutls/v"
+                             (string-join (take (string-split version #\.) 2)
+                                          ".")
+                             "/gnutls-" version ".tar.xz"))
              (sha256
               (base32
-               "0zvhzy87v9dfxfvmg1pl951kw55rp647cqdza8942fxq7spp158i"))))
+               "0195nliarszq5mginli6d2f5z7ljnd7mwa46iy9z8pkcgy56khbl"))))
     (build-system gnu-build-system)
+    (arguments
+     ;; Work around build issue reported at
+     ;; <https://lists.gnu.org/archive/html/guix-devel/2014-03/msg00027.html>.
+     '(#:make-flags '("CPPFLAGS=-DENABLE_RSA_EXPORT")))
     (native-inputs
      `(("pkg-config" ,pkg-config)))
     (inputs
