@@ -54,7 +54,8 @@
               "1c2hbg66wfvibsz2ia0ri48yr62751fn950i97c53j3b0fjifsb3"))))
    (build-system gnu-build-system)
    (inputs `(("glib" ,glib)
-             ("pkg-config" ,pkg-config)))
+             ("gobject-introspection" ,gobject-introspection)))
+   (native-inputs `(("pkg-config" ,pkg-config)))
    (synopsis "GNOME accessibility toolkit")
    (description
     "ATK provides the set of accessibility interfaces that are implemented
@@ -87,11 +88,12 @@ tools have full access to view and control running applications.")
    (inputs
     `(("ghostscript" ,ghostscript)
       ("libspectre" ,libspectre)
-      ("pkg-config" ,pkg-config)
       ("poppler" ,poppler)
-      ("python" ,python-wrapper)
       ("xextproto" ,xextproto)
       ("zlib" ,zlib)))
+   (native-inputs
+     `(("pkg-config" ,pkg-config)
+      ("python" ,python-wrapper)))
     (arguments
       `(#:tests? #f)) ; see http://lists.gnu.org/archive/html/bug-guix/2013-06/msg00085.html
    (synopsis "2D graphics library")
@@ -127,8 +129,9 @@ affine transformation (scale, rotation, shear, etc.)")
    (build-system gnu-build-system)
    (inputs
     `(("cairo" ,cairo)
-      ("icu4c" ,icu4c)
-      ("pkg-config" ,pkg-config)
+      ("icu4c" ,icu4c)))
+   (native-inputs
+     `(("pkg-config" ,pkg-config)
       ("python" ,python-wrapper)))
    (synopsis "opentype text shaping engine")
    (description
@@ -153,8 +156,10 @@ affine transformation (scale, rotation, shear, etc.)")
     `(("cairo" ,cairo)
       ("harfbuzz" ,harfbuzz)))
    (inputs
-    `(("pkg-config" ,pkg-config)
+    `(("gobject-introspection" ,gobject-introspection)
       ("zlib" ,zlib)))
+   (native-inputs
+    `(("pkg-config" ,pkg-config)))
    (synopsis "GNOME text and font handling library")
    (description
     "Pango is the core text and font handling library used in GNOME
@@ -178,14 +183,14 @@ used throughout the world.")
                 "07hrabhpl6n8ajz10s0d960jdwndxs87szxyn428mpxi8cvpg1f5"))))
     (build-system gnu-build-system)
     (inputs
-     `(("intltool" ,intltool)
-       ("pkg-config" ,pkg-config)
-       ("gtk" ,gtk+-2)
+     `(("gtk" ,gtk+-2)
        ("libxml2" ,libxml2)
-
        ;; These two are needed only to allow the tests to run successfully.
        ("xorg-server" ,xorg-server)
        ("shared-mime-info" ,shared-mime-info)))
+    (native-inputs
+      `(("intltool" ,intltool)
+       ("pkg-config" ,pkg-config)))
     (arguments
      `(#:phases
        ;; Unfortunately, some of the tests in "make check" are highly dependent
@@ -231,10 +236,12 @@ printing and other features typical of a source code editor.")
    (build-system gnu-build-system)
    (inputs
     `(("glib" ,glib)
+      ("gobject-introspection", gobject-introspection)
       ("libjpeg" ,libjpeg)
       ("libpng" ,libpng)
-      ("libtiff" ,libtiff)
-      ("pkg-config" ,pkg-config)))
+      ("libtiff" ,libtiff)))
+   (native-inputs
+     `(("pkg-config" ,pkg-config)))
    (synopsis "GNOME image loading and manipulation library")
    (description
     "GdkPixbuf is a library for image loading and manipulation developed
@@ -257,10 +264,11 @@ in the GNOME project.")
    (build-system gnu-build-system)
    (inputs `(("dbus" ,dbus)
              ("glib" ,glib)
-             ("intltool" ,intltool)
              ("libxi" ,libxi)
-             ("libxtst" ,libxtst)
-             ("pkg-config" ,pkg-config)))
+             ("libxtst" ,libxtst)))
+   (native-inputs
+     `(("intltool" ,intltool)
+       ("pkg-config" ,pkg-config)))
    (arguments
     `(#:tests? #f)) ; FIXME: dbind/dbtest fails; one should disable tests in
                     ; a more fine-grained way.
@@ -287,8 +295,9 @@ is part of the GNOME accessibility project.")
    (inputs `(("atk" ,atk)
              ("at-spi2-core" ,at-spi2-core)
              ("dbus" ,dbus)
-             ("glib" ,glib)
-             ("pkg-config" ,pkg-config)))
+             ("glib" ,glib)))
+   (native-inputs
+     `(("pkg-config" ,pkg-config)))
    (arguments
     `(#:tests? #f)) ; FIXME: droute/droute-test fails; one should disable
                     ; tests in a more fine-grained way.
@@ -316,20 +325,18 @@ is part of the GNOME accessibility project.")
     `(("atk" ,atk)
       ("gdk-pixbuf" ,gdk-pixbuf)
       ("pango" ,pango)))
-   (inputs
+   (native-inputs
     `(("perl" ,perl)
       ("pkg-config" ,pkg-config)
       ("python-wrapper" ,python-wrapper)))
    (arguments
     `(#:phases
-      (alist-replace
-       'configure
-       (lambda* (#:key #:allow-other-keys #:rest args)
-        (let ((configure (assoc-ref %standard-phases 'configure)))
-          ;; FIXME: re-enable tests requiring an X server
-          (substitute* "gtk/Makefile.in"
-           (("SUBDIRS = theme-bits . tests") "SUBDIRS = theme-bits ."))
-          (apply configure args)))
+      (alist-cons-before
+       'configure 'disable-tests
+       (lambda _
+         ;; FIXME: re-enable tests requiring an X server
+         (substitute* "gtk/Makefile.in"
+           (("SUBDIRS = theme-bits . tests") "SUBDIRS = theme-bits .")))
       %standard-phases)))
    (synopsis "Cross-platform toolkit for creating graphical user interfaces")
    (description
@@ -359,16 +366,24 @@ application suites.")
       ("libxinerama" ,libxinerama)
       ("pango" ,pango)))
    (inputs
-    `(("libxml2" ,libxml2)
-      ("perl" ,perl)
+    `(("gobject-introspection" ,gobject-introspection)
+      ("libxml2" ,libxml2)))
+   (native-inputs
+     `(("perl" ,perl)
       ("pkg-config" ,pkg-config)
       ("python-wrapper" ,python-wrapper)
       ("xorg-server" ,xorg-server)))
    (arguments
-    `(#:phases
+    `(#:modules ((guix build gnome)
+                 (guix build gnu-build-system)
+                 (guix build utils))
+      #:imported-modules ((guix build gnome)
+                          (guix build gnu-build-system)
+                          (guix build utils))
+      #:phases
       (alist-replace
        'configure
-       (lambda* (#:key #:allow-other-keys #:rest args)
+       (lambda* (#:key inputs #:allow-other-keys #:rest args)
          (let ((configure (assoc-ref %standard-phases 'configure)))
            ;; Disable most tests, failing in the chroot with the message:
            ;; D-Bus library appears to be incorrectly set up; failed to read
@@ -377,6 +392,31 @@ application suites.")
            ;; See the manual page for dbus-uuidgen to correct this issue.
            (substitute* "testsuite/Makefile.in"
             (("SUBDIRS = gdk gtk a11y css reftests") "SUBDIRS = gdk"))
+
+	   ;; We need to tell GIR where it can find some of the required .gir
+           ;; files.
+           (substitute* "gdk/Makefile.in"
+            (("--add-include-path=../gdk")
+             (string-append
+              "--add-include-path=../gdk"
+              " --add-include-path=" (gir-directory inputs "gdk-pixbuf")
+              " --add-include-path=" (gir-directory inputs "pango")))
+            (("--includedir=\\.")
+             (string-append "--includedir=."
+              " --includedir=" (gir-directory inputs "gdk-pixbuf")
+              " --includedir=" (gir-directory inputs "pango"))))
+
+           (substitute* "gtk/Makefile.in"
+            (("--add-include-path=../gdk")
+             (string-append "--add-include-path=../gdk"
+              " --add-include-path=" (gir-directory inputs "atk")
+              " --add-include-path=" (gir-directory inputs "gdk-pixbuf")
+              " --add-include-path=" (gir-directory inputs "pango")))
+            (("--includedir=../gdk")
+             (string-append "--includedir=../gdk"
+              " --includedir=" (gir-directory inputs "atk")
+              " --includedir=" (gir-directory inputs "gdk-pixbuf")
+              " --includedir=" (gir-directory inputs "pango"))))
            (apply configure args)))
        %standard-phases)))))
 
@@ -425,8 +465,9 @@ application suites.")
      `(("guile-lib" ,guile-lib)
        ("expat" ,expat)
        ("cairo" ,cairo)
-       ("pkg-config" ,pkg-config)
        ("guile" ,guile-2.0)))
+    (native-inputs
+      `(("pkg-config" ,pkg-config)))
     (home-page "http://www.nongnu.org/guile-cairo/")
     (synopsis "Cairo bindings for GNU Guile")
     (description
@@ -458,7 +499,7 @@ exceptions, macros, and a dynamic programming environment.")
     (arguments
      ;; The examples lack -lcairo.
      '(#:make-flags '("LDFLAGS=-lcairo")))
-    (inputs `(("pkg-config" ,pkg-config)))
+    (native-inputs `(("pkg-config" ,pkg-config)))
     (propagated-inputs
      `(("libsigc++" ,libsigc++)
        ("freetype" ,freetype)
@@ -483,7 +524,7 @@ library.")
               (base32
                "0hcyvv7c5zmivprdam6cp111i6hn2y5jsxzk00m6j9pncbzvp0hf"))))
     (build-system gnu-build-system)
-    (inputs `(("pkg-config" ,pkg-config)))
+    (native-inputs `(("pkg-config" ,pkg-config)))
     (propagated-inputs
      `(("cairo" ,cairo)
        ("cairomm" ,cairomm)
@@ -508,7 +549,7 @@ library.")
               (base32
                "06zrf2ymml2dzp53sss0d4ch4dk9v09jm8rglnrmwk4v81mq9gxz"))))
     (build-system gnu-build-system)
-    (inputs `(("pkg-config" ,pkg-config)))
+    (native-inputs `(("pkg-config" ,pkg-config)))
     (propagated-inputs
      `(("glibmm" ,glibmm) ("atk" ,atk)))
     (home-page "http://www.gtkmm.org")
@@ -530,7 +571,7 @@ toolkit.")
               (base32
                "0yf8wwv4w02p70nrxsbs0nhm0w4gkn2wggdjygd8vif062anf1rs"))))
     (build-system gnu-build-system)
-    (inputs `(("pkg-config" ,pkg-config)))
+    (native-inputs `(("pkg-config" ,pkg-config)))
     (propagated-inputs
      `(("pangomm" ,pangomm)
        ("cairomm" ,cairomm)
@@ -547,3 +588,22 @@ are easily extensible via inheritance.  You can create user interfaces either
 in code or with the Glade User Interface designer, using libglademm.  There's
 extensive documentation, including API reference and a tutorial.")
     (license license:lgpl2.1+)))
+
+
+(define-public gtkmm-2
+  (package (inherit gtkmm)
+    (version "2.24.2")
+    (source (origin
+             (method url-fetch)
+             (uri (string-append "mirror://gnome/sources/gtkmm/"
+                                 (string-take version 4) "/gtkmm-"
+                                 version ".tar.xz"))
+             (sha256
+              (base32
+               "0gcm91sc1a05c56kzh74l370ggj0zz8nmmjvjaaxgmhdq8lpl369"))))
+    (propagated-inputs
+     `(("pangomm" ,pangomm)
+       ("cairomm" ,cairomm)
+       ("atkmm" ,atkmm)
+       ("gtk+" ,gtk+-2)
+       ("glibmm" ,glibmm)))))
