@@ -37,24 +37,22 @@
             (sha256 (base32
                      "0wj8d1iwk9vnpax2h29xqc2hwknxg3s0ay2d5pxkg59ihbifn6pa"))))
    (build-system gnu-build-system)
-   (inputs `(("file" ,file)
-             ("zlib" ,zlib)
+   (inputs `(("zlib" ,zlib)
              ("libjpeg-8" ,libjpeg-8)))
              ;; currently does not compile with libjpeg version 9
+   (native-inputs `(("file" ,file)))
    (arguments
     `(#:configure-flags
       (list (string-append "--with-jpeg-include-dir="
                            (assoc-ref %build-inputs "libjpeg-8")
                            "/include"))
       #:phases
-      (alist-replace
-       'configure
-       (lambda* (#:key #:allow-other-keys #:rest args)
-        (let ((configure (assoc-ref %standard-phases 'configure)))
-          (substitute* "configure"
-            (("`/usr/bin/file")
-            (string-append "`" (which "file"))))
-          (apply configure args)))
+      (alist-cons-before
+       'configure 'patch-configure
+       (lambda _
+         (substitute* "configure"
+           (("`/usr/bin/file")
+            (string-append "`" (which "file")))))
       %standard-phases)))
    (synopsis "Libtiff, a library for handling TIFF files")
    (description
