@@ -1,5 +1,6 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2012, 2013 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2014 Mark H Weaver <mhw@netris.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -99,6 +100,11 @@
           ,(string-append "--includedir=" (assoc-ref %outputs "out")
                           "/include")
 
+          ;; By default man pages land in PREFIX/man, but we want them
+          ;; in PREFIX/share/man.
+          ,(string-append "--mandir=" (assoc-ref %outputs "out")
+                          "/share/man")
+
           ;; C++ bindings fail to build on
           ;; `i386-pc-solaris2.11' with GCC 3.4.3:
           ;; <http://bugs.opensolaris.org/bugdatabase/view_bug.do?bug_id=6395191>.
