@@ -53,9 +53,14 @@
     (inputs
      ;; XXX: add 'lvm2'.
      `(("check" ,check)
-       ("gettext" ,gnu-gettext)
-       ("readline" ,readline)
+
+       ;; With Readline 6.3, parted/ui.c fails to build because it uses the
+       ;; now undefined 'CPPFunction' type.
+       ("readline" ,readline-6.2)
+
        ("util-linux" ,util-linux)))
+    (native-inputs
+     `(("gettext" ,gnu-gettext)))
     (home-page "http://www.gnu.org/software/parted/")
     (synopsis "Disk partition editor")
     (description
